#
# spec file for package python-Deprecated
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-Deprecated
Version:        1.2.14
Release:        3.1
Summary:        Python @deprecated decorator
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/tantale/deprecated
Source:         https://files.pythonhosted.org/packages/source/D/Deprecated/Deprecated-%{version}.tar.gz
# PATCH-FIX-UPSTREAM - gh#tantale/deprecated/73 - Update class method deprecation warnings for Python 3.13
Patch1:         https://github.com/tantale/deprecated/pull/73.patch#/fix-python3.13-ftbfs.patch
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wrapt >= 1.10}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-wrapt >= 1.10
BuildArch:      noarch
Provides:       python-deprecated = %{version}-%{release}
%python_subpackages

%description
If you need to mark a function or a method as deprecated,
you can use the ``@deprecated`` decorator.

%prep
%setup -q -n Deprecated-%{version}
%patch -P 1 -p1

%build
%python_build

%install
%python_install
# Fix python-bytecode-inconsistent-mtime
pushd %{buildroot}%{python_sitelib}
find . -name '*.pyc' -exec rm -f '{}' ';'
python%python_bin_suffix -m compileall *.py ';'
popd
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGELOG.rst README.md
%license LICENSE.rst
%{python_sitelib}/deprecated
%{python_sitelib}/Deprecated-%{version}*-info

%changelog
* Tue Sep 24 2024 ecsos <ecsos@opensuse.org>
- Fix build error under Leap.
* Mon Jul 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix build with Python 3.13
  * fix-python3.13-ftbfs.patch
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.14:
  * Bug fix release
  * Fix return a correctly dedented docstring when long
    docstring are using the D212 or D213 format.
  * Add support for Python 3.11.
  * Drop support for Python older than 3.7 in build systems like
    pytest and tox, while ensuring the library remains
    production-compatible.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Oct 31 2022 Ben Greiner <code@bnavigator.de>
- Provid canonicalized lowercase name
- Don't catchall files section
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.13:
  * Change the signature of the :func:`~deprecated.sphinx.deprecated` decorator to reflect
    the valid use cases.
  * Fix ``versionadded`` and ``versionchanged`` decorators: do not return a decorator factory,
    but a Wrapt adapter.
  * change the requirements for ``pip`` to "pip >= 9.0.3, < 21" (Python 2.7, 3.4 and 3.5).
  * install ``typing`` when building on Python 3.4 (required by Pytest->Attrs).
  * run unit tests on Wrapt 1.13 (release candidate).
* Sun Apr 18 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.2.12
  * Avoid "Explicit markup ends without a blank line" when the
    decorated function has no docstring.
  * Fix #40: 'version' argument is required in Sphinx directives.
  * Fix #41: deprecated.sphinx: strip Sphinx cross-referencing
    syntax from warning message.
- Release 1.2.11
  * Fix packit configuration: use upstream_tag_template: v{version}.
  * Fix #33: Change the class ~deprecated.sphinx.SphinxAdapter: add
    the line_length keyword argument to the constructor to specify
    the max line length of the directive text. Sphinx decorators
    also accept the line_length argument.
  * Fix #34: versionadded and versionchanged decorators don't emit
    DeprecationWarning anymore on decorated classes.
* Wed Jul  8 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 1.2.10
  * Fix #25: @deprecated respects global warning filters with actions other
    than “ignore” and “always” on Python 3.
* Mon May  4 2020 Johannes Grassler <johannes.grassler@suse.com>
- update to 1.2.9
  * Fix #20: Set the :func:warnings.warn stacklevel to 2 if
    the Python implementation is PyPy
  * Fix packit configuration: use dist-git-branch: fedora-all
  * Change the Tox configuration to run tests on PyPy v2.7 and 3.6.
  * Fix #15: The @deprecated decorator doesn't set a warning
    filter if the action keyword argument is not provided or None.
  * Fix #13: Warning displays the correct filename and line
    number when decorating a class if wrapt does not have the compiled c
    extension.
* Mon Jan 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.2.7
  * Fix: Warning displays the correct filename and line number when
    decorating a function if wrapt does not have the compiled c extension.
  * Add Black configuration file.
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.6:
  * Fix #9: Change the project's configuration: reinforce the constraint to the Wrapt requirement.
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by PyGithub
